@@ -7,6 +7,7 @@ except ImportError:
 	vim = object()
 
 from powerline.segments.vim import window_cached
+from powerline.bindings.vim import vim_global_exists
 
 
 @window_cached
@@ -19,10 +20,10 @@ def syntastic(pl, err_format='ERR:  {first_line} ({num}) ', warn_format='WARN
 	:param str warn_format:
 		Format string for warnings.
 
-	Highlight groups used: ``syntastic.warning`` or ``warning``, ``syntastic.error`` or ``error``.
+	Highlight groups used: ``syntastic:warning`` or ``warning``, ``syntastic:error`` or ``error``.
 	'''
-	if not int(vim.eval('exists("g:SyntasticLoclist")')):
-		return
+	if not vim_global_exists('SyntasticLoclist'):
+		return None
 	has_errors = int(vim.eval('g:SyntasticLoclist.current().hasErrorsOrWarningsToDisplay()'))
 	if not has_errors:
 		return
@@ -32,11 +33,11 @@ def syntastic(pl, err_format='ERR:  {first_line} ({num}) ', warn_format='WARN
 	if errors:
 		segments.append({
 			'contents': err_format.format(first_line=errors[0]['lnum'], num=len(errors)),
-			'highlight_group': ['syntastic.error', 'error'],
+			'highlight_groups': ['syntastic:error', 'error'],
 		})
 	if warnings:
 		segments.append({
 			'contents': warn_format.format(first_line=warnings[0]['lnum'], num=len(warnings)),
-			'highlight_group': ['syntastic.warning', 'warning'],
+			'highlight_groups': ['syntastic:warning', 'warning'],
 		})
 	return segments
