@@ -6,6 +6,7 @@ import os
 import sys
 import re
 import shutil
+import unicodedata
 
 from time import sleep
 from subprocess import call, PIPE
@@ -497,22 +498,14 @@ class TestUnicode(TestCase):
 		if sys.maxunicode < 0x10FFFF:
 			raise SkipTest('Can only test strwidth_ucs_4 in UCS-4 Pythons')
 
-		def east_asian_width(ch):
-			assert (len(ch) == 1)
-			assert ord(ch) == 0x1F48E
-			return 'F'
-
-		with replace_attr(plu, 'east_asian_width', east_asian_width):
-			# Warning: travis unicodedata.east_asian_width for some reason 
-			# thinks this character is 5 symbols wide.
-			self.assertEqual(2, plu.strwidth_ucs_4(width_data, '\U0001F48E'))
+		self.assertEqual(1, plu.strwidth_ucs_4(width_data, '\U0001F063'))
 
 	def test_strwidth_ucs_2(self):
 		self.assertEqual(4, plu.strwidth_ucs_2(width_data, 'abcd'))
 		self.assertEqual(4, plu.strwidth_ucs_2(width_data, 'ＡＢ'))
 		if not sys.maxunicode < 0x10FFFF:
 			raise SkipTest('Can only test strwidth_ucs_2 in UCS-2 Pythons')
-		self.assertEqual(2, plu.strwidth_ucs_2(width_data, '\ud83d\udc8e'))
+		self.assertEqual(1, plu.strwidth_ucs_2(width_data, '\ud83c\udc30'))
 
 
 class TestVCS(TestCase):
